@@ -13,13 +13,21 @@ def compile_string(string, *, filename=None) -> static.CubModule:
 	if parser.errors:
 		raise ValueError("Unable to compile cubicle module.") from None
 	else:
-		return middle.Transducer(parser.source).interpret(declarations)
+		try: return middle.Transducer(parser.source).interpret(declarations)
+		except middle.SemanticError as e:
+			e.show(parser.source)
+			raise e from None
 
 def compile_path(path) -> static.CubModule:
 	with open(path) as fh: string = fh.read()
 	return compile_string(string, filename=path)
 
 def main():
+	"""
+	Compile cubicle module definitions into pickle files. Eventually.
+	Incidentally, it would be nice to make the packaging system expose
+	this sub-module as a script.
+	"""
 	import sys, argparse
 	print("Not ready for prime time. Check back each Saturday night.", file=sys.stderr)
 	exit(1)
