@@ -199,7 +199,7 @@ class Transducer(foundation.Visitor):
 						candef.style_rules.append(veneer.Rule(selector, style_index(patch.style_points)))
 					content = patch.content
 					if isinstance(content, list):
-						content = selection_context.translate_formula(content)
+						content = stylist.selpass.translate_formula(content)
 					if patch.is_merge:
 						candef.merge_specs.append(veneer.Rule(selector, content))
 					elif content:
@@ -469,8 +469,14 @@ class SelectionPass(foundation.Visitor):
 		return formulae.Selection(self.criteria)
 	
 	def translate_formula(self, bits) -> formulae.Formula:
-		return formulae.Formula([self.translate_selection(b) if isinstance(b, list) else b for b in bits])
+		return formulae.Formula([self.visit(b) for b in bits])
 	
 	def subordinate_context(self, criteria:List[Union[AST.Criterion, AST.Sigil]]) -> "SelectionPass":
 		self.apply_criteria(criteria)
 		return SelectionPass(self.zones, self.criteria)
+	
+	def visit_LiteralText(self, item): return item
+	def visit_Quotation(self, item): return item
+	def visit_RawRange(self, rr:AST.RawRange): return self.translate_selection(rr.criteria)
+	def visit_MagicSum(self, ms:AST.MagicSum): return formulae.Summation(self.translate_selection(ms.criteria))
+	
